@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
-version: 2.2.1
-id: persistent-sqlite-2.2.1-aa424decdef328ca64546d2eb6a9df69
-key: persi_1rYAjWt8OalCiu6IoW2luf
+version: 2.2
+id: persistent-sqlite-2.2-fbe400fcfe3c6dde6b15fc47ef9a114d
+key: persi_2H0sIBypEBa35SrkiZcs7h
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -17,24 +17,24 @@ exposed: True
 exposed-modules:
     Database.Sqlite Database.Persist.Sqlite
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-1rYAjWt8OalCiu6IoW2luf
+import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2
+hs-libraries: HSpersistent-sqlite-2.2-2H0sIBypEBa35SrkiZcs7h
 extra-libraries:
     pthread
 depends:
-    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
+    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
+    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-53b32e0b8931dd68fbb356ac374c65f3
-    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    persistent-2.2.4-7522deb7fd39c262180984fc189631e9
+    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
+    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
